gam_to_psi: map warping function to hilbert sphere
Description
map warping function to hilbert sphere
Usage
gam_to_psi(gam, smooth = TRUE)
Value
A numeric array of the same shape as the input array gamma storing the
shooting vectors of gamma obtained via finite differences.
Arguments
- gam
Either a numeric vector of a numeric matrix or a numeric array
specifying the warping functions
- smooth
Apply smoothing before gradient