This function calculates amplitude and phase joint functional principal component analysis on aligned data using the SRVF framework using MFPCA and h representation
jointFPCAh(
warp_data,
var_exp = 0.99,
id = round(length(warp_data$time)/2),
C = NULL,
ci = c(-1, 0, 1),
srvf = TRUE,
showplot = TRUE
)Returns a list containing
srvf principal directions
f principal directions
latent values
coefficients
eigenvectors
mean psi function
mean g function
point use for f(0)
optimized phase amplitude ratio
fdawarp object from time_warping of aligned data
compute no based on value percent variance explained (default: 0.99)
will override no
integration point for f0 (default = midpoint)
balance value (default = NULL)
geodesic standard deviations (default = c(-1,0,1))
use srvf (default = TRUE)
show plots of principal directions (default = T)
Srivastava, A., Wu, W., Kurtek, S., Klassen, E., Marron, J. S., May 2011. Registration of functional data using fisher-rao metric, arXiv:1103.3817v2.
Happ, C., Scheipl, F., Gabriel, A. & Greven, S. A general framework for multivariate functional principal component analysis of amplitude and phase variation. Stat 8, (2019).
Ma, Y., Zhou, X. & Wu, W. A stochastic process representation for time warping functions. Comput. Stat. Data Anal. 194, 107941 (2024).
Tucker, J. D., Wu, W., Srivastava, A., Generative Models for Function Data using Phase and Amplitude Separation, Computational Statistics and Data Analysis (2012), 10.1016/j.csda.2012.12.001.
jfpcah <- jointFPCAh(simu_warp)
Run the code above in your browser using DataLab