Learn R Programming

fdasrvf (version 2.5.0)

psi_to_gam: map hilbert sphere to warping function

Description

map hilbert sphere to warping function

Usage

psi_to_gam(psi)

Value

A numeric array of the same shape as the input array psi storing the warping functions psi.

Arguments

psi

Either a numeric vector of a numeric matrix or a numeric array specifying the shooting vectors