map shooting vector to curve at mean
v_to_curve(v, mu, mode = "O", scale = 1)A numeric array of the same shape as the input array v storing the
curves of v.
Either a numeric vector of a numeric matrix or a numeric array specifying the shooting vectors
vector describing the mean
A character string specifying whether the input curves should be
considered open (mode == "O") or closed (mode == "C"). Defaults to
"O".
original scale of curve