powered by
map hilbert sphere to warping function
psi_to_gam(psi)
A numeric array of the same shape as the input array psi storing the warping functions psi.
psi
Either a numeric vector of a numeric matrix or a numeric array specifying the shooting vectors